# -*- coding: utf-8 -*-
"""
Created on Thu Mar  3 11:22:03 2022

@author: Wahb
"""
# In[0] - Importation de bibliothèques

import pandas as pd
from sklearn import svm
from sklearn.preprocessing import MinMaxScaler
from sklearn.model_selection import train_test_split 
from sklearn.metrics import confusion_matrix


# In[1] - Prétraitement de données

## Importation de jeu de données
data = pd.read_excel(r'C:/Users/2016-1951/Desktop/5vs7.xlsx')   # importer le fichier de données excel
noms_params = data.columns

## Normalisation de jeu de données
data = data.to_numpy()                                                                              # convertir en NumPy array 
scaling = MinMaxScaler()                                                                            # mettre toutes les valeurs dans l'intervalle [0,1]. 
data = scaling.fit_transform(data)

## Fractionnement des données 70%-20%-10%
X = data[:,:-1]                                                                                     # définir les paramètres/attributs
y = data[:,-1]                                                                                      # définir les étiquettes (dernière colonne)
X_train, X_test, y_train, y_test = train_test_split(X, y,                                           # définir le jeu de test
                            test_size = 2/10, random_state = 42)                                                                      

# In[2] - Classification par SVM (cas linéaire)

## Entraînement et réglage du modèle 
model = svm.SVC(kernel='linear')
model.fit(X_train, y_train)

## Evaluation et prédiction 
print("Précision de prédiction - SVM linéaire :")
print(" - Jeu d'apprentissage': {:.2%}".format(model.score(X_train, y_train)))
print(" - Jeu de test: {:.2%}".format(model.score(X_test, y_test)))

# In[3] -  Matrice de confusion (cas linéaire)

y_pred = model.predict(X_test)
Mat_conf = pd.DataFrame(data=confusion_matrix(y_test, y_pred),
             columns=["Positif réel", "Négatif réel"], index= ["Positif prédit", "Négatif prédit"])
print("Matrice de confusion :\n", Mat_conf)

# In[4] - Classification par SVM (cas non-linéaire)

## Entraînement et réglage du modèle 
model = svm.SVC(kernel='rbf', C=1.0, gamma='scale')        # modifier C et gamma pour optimiser les performances du modèle
model.fit(X_train, y_train)

## Evaluation et prédiction 
print("Précision de prédiction - SVM non linéaire :")
print(" - Jeu d'apprentissage': {:.2%}".format(model.score(X_train, y_train)))
print(" - Jeu de test: {:.2%}".format(model.score(X_test, y_test)))

# In[5] -  Matrice de confusion (cas non-linéaire)

y_pred = model.predict(X_test)
Mat_conf = pd.DataFrame(data=confusion_matrix(y_test, y_pred),
             columns=["Positif réel", "Négatif réel"], index= ["Positif prédit", "Négatif prédit"])
print("Matrice de confusion :\n", Mat_conf)
